@@ -40,16 +40,13 @@ CONF = cfg.CONF
 
 class ImageDataController(object):
     def __init__(self, db_api=None, store_api=None,
-                 policy_enforcer=None, notifier=None,
-                 gateway=None):
-        if gateway is None:
-            db_api = db_api or glance.db.get_api()
-            store_api = store_api or glance_store
-            policy = policy_enforcer or glance.api.policy.Enforcer()
-            notifier = notifier or glance.notifier.Notifier()
-            gateway = glance.gateway.Gateway(db_api, store_api,
-                                             notifier, policy)
-        self.gateway = gateway
+                 policy_enforcer=None, notifier=None):
+        db_api = db_api or glance.db.get_api()
+        store_api = store_api or glance_store
+        notifier = notifier or glance.notifier.Notifier()
+        self.policy = policy_enforcer or glance.api.policy.Enforcer()
+        self.gateway = glance.gateway.Gateway(db_api, store_api,
+                                              notifier, self.policy)
 
     def _restore(self, image_repo, image):
         """
@@ -108,6 +105,7 @@ class ImageDataController(object):
         refresher = None
         cxt = req.context
         try:
+            self.policy.enforce(cxt, 'upload_image', {})
             image = image_repo.get(image_id)
             image.status = 'saving'
             try:
@@ -299,11 +297,15 @@ class ImageDataController(object):
             image.status = 'uploading'
             image_repo.save(image, from_state='queued')
             try:
-                staging_store.add(image_id, data, 0)
+                staging_store.add(
+                    image_id, utils.LimitingReader(
+                        utils.CooperativeReader(data), CONF.image_size_cap), 0)
             except glance_store.Duplicate as e:
                 msg = _("The image %s has data on staging") % image_id
                 raise webob.exc.HTTPConflict(explanation=msg)
-                self._restore(image_repo, image)
+
+        except exception.NotFound as e:
+            raise webob.exc.HTTPNotFound(explanation=e.msg)
 
         except glance_store.StorageFull as e:
             msg = _("Image storage media "
@@ -333,10 +335,15 @@ class ImageDataController(object):
             msg = _("Insufficient permissions on image "
                     "storage media: %s") % encodeutils.exception_to_unicode(e)
             LOG.error(msg)
-            self._unstage(image_repo, image)
+            self._unstage(image_repo, image, staging_store)
             raise webob.exc.HTTPServiceUnavailable(explanation=msg,
                                                    request=req)
 
+        except exception.InvalidImageStatusTransition as e:
+            msg = encodeutils.exception_to_unicode(e)
+            LOG.debug(msg)
+            raise webob.exc.HTTPConflict(explanation=e.msg, request=req)
+
         except Exception as e:
             with excutils.save_and_reraise_exception():
                 LOG.exception(_LE("Failed to stage image data due to "
