@@ -17,7 +17,8 @@ import collections
 import copy
 
 from cryptography import exceptions as crypto_exception
-import debtcollector
+from cursive import exception as cursive_exception
+from cursive import signature_utils
 import glance_store as store
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -25,10 +26,9 @@ from oslo_utils import encodeutils
 from oslo_utils import excutils
 
 from glance.common import exception
-from glance.common import signature_utils
 from glance.common import utils
 import glance.domain.proxy
-from glance.i18n import _, _LE, _LI
+from glance.i18n import _, _LE, _LI, _LW
 
 
 CONF = cfg.CONF
@@ -74,12 +74,11 @@ class ImageRepoProxy(glance.domain.proxy.Repo):
 
 
 def _get_member_repo_for_store(image, context, db_api, store_api):
-        image_member_repo = glance.db.ImageMemberRepo(
-            context, db_api, image)
-        store_image_repo = glance.location.ImageMemberRepoProxy(
-            image_member_repo, image, context, store_api)
+    image_member_repo = glance.db.ImageMemberRepo(context, db_api, image)
+    store_image_repo = glance.location.ImageMemberRepoProxy(
+        image_member_repo, image, context, store_api)
 
-        return store_image_repo
+    return store_image_repo
 
 
 def _check_location_uri(context, store_api, store_utils, uri):
@@ -161,10 +160,12 @@ class ImageFactoryProxy(glance.domain.proxy.ImageFactory):
 
 class StoreLocations(collections.MutableSequence):
     """
-    The proxy for store location property. It takes responsibility for:
-    1. Location uri correctness checking when adding a new location.
-    2. Remove the image data from the store when a location is removed
-       from an image.
+    The proxy for store location property. It takes responsibility for::
+
+        1. Location uri correctness checking when adding a new location.
+        2. Remove the image data from the store when a location is removed
+           from an image.
+
     """
     def __init__(self, image_proxy, value):
         self.image_proxy = image_proxy
@@ -302,6 +303,9 @@ class StoreLocations(collections.MutableSequence):
     def __eq__(self, other):
         return self.value == self.__cast(other)
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     def __iter__(self):
         return iter(self.value)
 
@@ -407,12 +411,21 @@ class ImageProxy(glance.domain.proxy.Image):
 
         # Create the verifier for signature verification (if correct properties
         # are present)
-        if (signature_utils.should_create_verifier(
-                self.image.extra_properties)):
+        extra_props = self.image.extra_properties
+        if (signature_utils.should_create_verifier(extra_props)):
             # NOTE(bpoulos): if creating verifier fails, exception will be
             # raised
+            img_signature = extra_props[signature_utils.SIGNATURE]
+            hash_method = extra_props[signature_utils.HASH_METHOD]
+            key_type = extra_props[signature_utils.KEY_TYPE]
+            cert_uuid = extra_props[signature_utils.CERT_UUID]
             verifier = signature_utils.get_verifier(
-                self.context, self.image.extra_properties)
+                context=self.context,
+                img_signature_certificate_uuid=cert_uuid,
+                img_signature_hash_method=hash_method,
+                img_signature=img_signature,
+                img_signature_key_type=key_type
+            )
         else:
             verifier = None
 
@@ -425,8 +438,6 @@ class ImageProxy(glance.domain.proxy.Image):
             context=self.context,
             verifier=verifier)
 
-        self._verify_signature_if_needed(checksum)
-
         # NOTE(bpoulos): if verification fails, exception will be raised
         if verifier:
             try:
@@ -434,7 +445,7 @@ class ImageProxy(glance.domain.proxy.Image):
                 LOG.info(_LI("Successfully verified signature for image %s"),
                          self.image.image_id)
             except crypto_exception.InvalidSignature:
-                raise exception.SignatureVerificationError(
+                raise cursive_exception.SignatureVerificationError(
                     _('Signature verification failed')
                 )
 
@@ -444,19 +455,6 @@ class ImageProxy(glance.domain.proxy.Image):
         self.image.checksum = checksum
         self.image.status = 'active'
 
-    @debtcollector.removals.remove(
-        message="This will be removed in the N cycle.")
-    def _verify_signature_if_needed(self, checksum):
-        # Verify the signature (if correct properties are present)
-        if (signature_utils.should_verify_signature(
-                self.image.extra_properties)):
-            # NOTE(bpoulos): if verification fails, exception will be raised
-            result = signature_utils.verify_signature(
-                self.context, checksum, self.image.extra_properties)
-            if result:
-                LOG.info(_LI("Successfully verified signature for image %s"),
-                         self.image.image_id)
-
     def get_data(self, offset=0, chunk_size=None):
         if not self.image.locations:
             # NOTE(mclaren): This is the only set of arguments
@@ -476,8 +474,8 @@ class ImageProxy(glance.domain.proxy.Image):
 
                 return data
             except Exception as e:
-                LOG.warn(_('Get image %(id)s data failed: '
-                           '%(err)s.')
+                LOG.warn(_LW('Get image %(id)s data failed: '
+                             '%(err)s.')
                          % {'id': self.image.image_id,
                             'err': encodeutils.exception_to_unicode(e)})
                 err = e
