@@ -18,6 +18,7 @@ __all__ = [
     'list_scrubber_opts',
     'list_cache_opts',
     'list_manage_opts',
+    'list_image_import_opts',
 ]
 
 import copy
@@ -27,7 +28,10 @@ from osprofiler import opts as profiler
 
 import glance.api.middleware.context
 import glance.api.versions
+import glance.async.flows._internal_plugins
+import glance.async.flows.api_image_import
 import glance.async.flows.convert
+from glance.async.flows.plugins import plugin_opts
 import glance.async.taskflow_executor
 import glance.common.config
 import glance.common.location_strategy
@@ -90,10 +94,7 @@ _scrubber_opts = [
         glance.common.config.common_opts,
         glance.scrubber.scrubber_opts,
         glance.scrubber.scrubber_cmd_opts,
-        glance.scrubber.scrubber_cmd_cli_opts,
-        glance.registry.client.registry_client_opts,
-        glance.registry.client.registry_client_ctx_opts,
-        glance.registry.registry_addr_opts))),
+        glance.scrubber.scrubber_cmd_cli_opts))),
 ]
 _cache_opts = [
     (None, list(itertools.chain(
@@ -107,6 +108,11 @@ _cache_opts = [
 _manage_opts = [
     (None, [])
 ]
+_image_import_opts = [
+    ('image_import_opts', glance.async.flows.api_image_import.api_import_opts),
+    ('import_filtering_opts',
+     glance.async.flows._internal_plugins.import_filtering_opts),
+]
 
 
 def list_api_opts():
@@ -153,3 +159,11 @@ def list_cache_opts():
 def list_manage_opts():
     """Return a list of oslo_config options available in Glance manage."""
     return [(g, copy.deepcopy(o)) for g, o in _manage_opts]
+
+
+def list_image_import_opts():
+    """Return a list of oslo_config options available for Image Import"""
+
+    opts = copy.deepcopy(_image_import_opts)
+    opts.extend(plugin_opts.get_plugin_opts())
+    return [(g, copy.deepcopy(o)) for g, o in opts]
