@@ -24,6 +24,7 @@ from oslo_config import cfg
 from six.moves import range
 
 from glance.common import exception
+from glance.db.sqlalchemy import api as db_api
 from glance import scrubber
 from glance.tests import utils as test_utils
 
@@ -51,9 +52,6 @@ class TestScrubber(test_utils.BaseTestCase):
         uri = 'file://some/path/%s' % uuid.uuid4()
         id = 'helloworldid'
         scrub = scrubber.Scrubber(glance_store)
-        scrub.registry = self.mox.CreateMockAnything()
-        scrub.registry.get_image(id).AndReturn({'status': 'pending_delete'})
-        scrub.registry.update_image(id, {'status': 'deleted'})
         self.mox.StubOutWithMock(glance_store, "delete_from_backend")
         glance_store.delete_from_backend(
             uri,
@@ -62,21 +60,20 @@ class TestScrubber(test_utils.BaseTestCase):
         scrub._scrub_image(id, [(id, '-', uri)])
         self.mox.VerifyAll()
 
-    def test_store_delete_successful(self):
+    @mock.patch.object(db_api, "image_get")
+    def test_store_delete_successful(self, mock_image_get):
         uri = 'file://some/path/%s' % uuid.uuid4()
         id = 'helloworldid'
 
         scrub = scrubber.Scrubber(glance_store)
-        scrub.registry = self.mox.CreateMockAnything()
-        scrub.registry.get_image(id).AndReturn({'status': 'pending_delete'})
-        scrub.registry.update_image(id, {'status': 'deleted'})
         self.mox.StubOutWithMock(glance_store, "delete_from_backend")
         glance_store.delete_from_backend(uri, mox.IgnoreArg()).AndReturn('')
         self.mox.ReplayAll()
         scrub._scrub_image(id, [(id, '-', uri)])
         self.mox.VerifyAll()
 
-    def test_store_delete_store_exceptions(self):
+    @mock.patch.object(db_api, "image_get")
+    def test_store_delete_store_exceptions(self, mock_image_get):
         # While scrubbing image data, all store exceptions, other than
         # NotFound, cause image scrubbing to fail. Essentially, no attempt
         # would be made to update the status of image.
@@ -86,7 +83,6 @@ class TestScrubber(test_utils.BaseTestCase):
         ex = glance_store.GlanceStoreException()
 
         scrub = scrubber.Scrubber(glance_store)
-        scrub.registry = self.mox.CreateMockAnything()
         self.mox.StubOutWithMock(glance_store, "delete_from_backend")
         glance_store.delete_from_backend(
             uri,
@@ -95,7 +91,8 @@ class TestScrubber(test_utils.BaseTestCase):
         scrub._scrub_image(id, [(id, '-', uri)])
         self.mox.VerifyAll()
 
-    def test_store_delete_notfound_exception(self):
+    @mock.patch.object(db_api, "image_get")
+    def test_store_delete_notfound_exception(self, mock_image_get):
         # While scrubbing image data, NotFound exception is ignored and image
         # scrubbing succeeds
         uri = 'file://some/path/%s' % uuid.uuid4()
@@ -103,9 +100,6 @@ class TestScrubber(test_utils.BaseTestCase):
         ex = glance_store.NotFound(message='random')
 
         scrub = scrubber.Scrubber(glance_store)
-        scrub.registry = self.mox.CreateMockAnything()
-        scrub.registry.get_image(id).AndReturn({'status': 'pending_delete'})
-        scrub.registry.update_image(id, {'status': 'deleted'})
         self.mox.StubOutWithMock(glance_store, "delete_from_backend")
         glance_store.delete_from_backend(uri, mox.IgnoreArg()).AndRaise(ex)
         self.mox.ReplayAll()
@@ -141,11 +135,12 @@ class TestScrubDBQueue(test_utils.BaseTestCase):
         image_pager = ImagePager(images)
 
         def make_get_images_detailed(pager):
-            def mock_get_images_detailed(filters, marker=None):
+            def mock_get_images_detailed(ctx, filters, marker=None,
+                                         limit=None):
                 return pager()
             return mock_get_images_detailed
 
-        with patch.object(scrub_queue.registry, 'get_images_detailed') as (
+        with patch.object(db_api, 'image_get_all') as (
                 _mock_get_images_detailed):
             _mock_get_images_detailed.side_effect = (
                 make_get_images_detailed(image_pager))
@@ -159,11 +154,12 @@ class TestScrubDBQueue(test_utils.BaseTestCase):
         image_pager = ImagePager(images, page_size=4)
 
         def make_get_images_detailed(pager):
-            def mock_get_images_detailed(filters, marker=None):
+            def mock_get_images_detailed(ctx, filters, marker=None,
+                                         limit=None):
                 return pager()
             return mock_get_images_detailed
 
-        with patch.object(scrub_queue.registry, 'get_images_detailed') as (
+        with patch.object(db_api, 'image_get_all') as (
                 _mock_get_images_detailed):
             _mock_get_images_detailed.side_effect = (
                 make_get_images_detailed(image_pager))
