@@ -32,10 +32,7 @@ import glance.tests.unit.utils as unit_test_utils
 class TestUploadUtils(base.StoreClearingUnitTest):
     def setUp(self):
         super(TestUploadUtils, self).setUp()
-        self.config(verbose=True, debug=True)
-
-    def tearDown(self):
-        super(TestUploadUtils, self).tearDown()
+        self.config(debug=True)
 
     def test_initiate_delete(self):
         req = unit_test_utils.get_fake_request()
@@ -110,9 +107,6 @@ class TestUploadUtils(base.StoreClearingUnitTest):
         yield (location, checksum, image_meta, image_data, store, notifier,
                update_data)
 
-        store.add.assert_called_once_with(image_meta['id'], mock.ANY,
-                                          image_meta['size'], context=mock.ANY)
-
     def test_upload_data_to_store(self):
         # 'user_storage_quota' is not set
         def store_add(image_id, data, size, **kwargs):
