@@ -279,6 +279,12 @@ class TestImageMembersController(test_utils.BaseTestCase):
         self.assertEqual(UUID2, output.image_id)
         self.assertEqual(TENANT3, output.member_id)
 
+    def test_member_create_raises_bad_request_for_unicode_value(self):
+        request = unit_test_utils.get_fake_request()
+        self.assertRaises(webob.exc.HTTPBadRequest, self.controller.create,
+                          request, image_id=UUID5,
+                          member_id=u'\U0001f693')
+
     def test_update_done_by_member(self):
         request = unit_test_utils.get_fake_request(tenant=TENANT4)
         image_id = UUID2
