@@ -15,10 +15,6 @@
 
 """Common utilities used in testing"""
 
-# NOTE(rosmaita): mriedem says this is needed for importing from fixtures,
-# and he's right!
-from __future__ import absolute_import
-
 import errno
 import functools
 import os
@@ -47,10 +43,10 @@ from glance.common import timeutils
 from glance.common import utils
 from glance.common import wsgi
 from glance import context
-from glance.db import migration as db_migration
 from glance.db.sqlalchemy import alembic_migrations
 from glance.db.sqlalchemy import api as db_api
 from glance.db.sqlalchemy import models as db_models
+from glance.tests.unit import fixtures as glance_fixtures
 
 CONF = cfg.CONF
 try:
@@ -88,6 +84,9 @@ class BaseTestCase(testtools.TestCase):
         utils.safe_mkdirs(self.conf_dir)
         self.set_policy()
 
+        # Limit the amount of DeprecationWarning messages in the unit test logs
+        self.useFixture(glance_fixtures.WarningsFixture())
+
     def set_policy(self):
         conf_file = "policy.json"
         self.policy_file = self._copy_data_file(conf_file, self.conf_dir)
@@ -682,10 +681,8 @@ class HttplibWsgiAdapter(object):
                                 response.body)
 
 
-def db_sync(version=None, engine=None):
+def db_sync(version='heads', engine=None):
     """Migrate the database to `version` or the most recent version."""
-    if version is None:
-        version = db_migration.LATEST_REVISION
     if engine is None:
         engine = db_api.get_engine()
 
